from netbox.views import generic

from netbox_storage.forms import LVSimpleForm, LVMSimpleForm
from netbox_storage.models import LinuxVolume, LogicalVolume, Drive


class LVMAddSimpleView(generic.ObjectEditView):
    """View for editing a Drive instance."""

    queryset = Drive.objects.all()
    form = LVMSimpleForm
    default_return_url = "plugins:netbox_storage:drive_list"


class LVAddSimpleView(generic.ObjectEditView):
    """View for editing a Drive instance."""

    queryset = LinuxVolume.objects.all()
    form = LVSimpleForm
    default_return_url = "plugins:netbox_storage:drive_list"


class AddVolume(generic.ObjectEditView):
    """View for editing a Drive instance."""
    template_name = "netbox_storage/inc/volume_add.html"
    queryset = Drive.objects.all()
    form = LVSimpleForm
    default_return_url = "plugins:netbox_storage:drive_list"



import django_tables2 as tables

from netbox.tables import (
    NetBoxTable,
    ToggleColumn,
    ActionsColumn,
)

from netbox_storage.models import LogicalVolume


class LogicalVolumeTable(NetBoxTable):
    """Table for displaying LogicalVolume objects."""

    pk = ToggleColumn()
    fs = tables.Column(
        linkify=True,
        verbose_name="Filesystem"
    )
    vg = tables.Column(
        linkify=True,
        verbose_name="Volume Group Name"
    )
    lv_name = tables.Column(
        linkify=True,
        verbose_name="Logical Volume Name"
    )

    class Meta(NetBoxTable.Meta):
        model = LogicalVolume
        fields = (
            "pk",
            "vg",
            "lv_name",
            "path",
            "fs",
            "description",
        )
        default_columns = (
            "vg",
            "lv_name",
            "path",
            "fs",
            "description"
        )
